==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/solutions/kotlin/inputs/ApplicationPackageLockingPolicyDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.solutions.kotlin.inputs

import com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Managed application locking policy.
 * @property allowedActions The deny assignment excluded actions.
 * @property allowedDataActions The deny assignment excluded data actions.
 */
public data class ApplicationPackageLockingPolicyDefinitionArgs(
    public val allowedActions: Output<List<String>>? = null,
    public val allowedDataActions: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs =
        com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs.builder()
            .allowedActions(allowedActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .allowedDataActions(
                allowedDataActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationPackageLockingPolicyDefinitionArgs].
 */
@PulumiTagMarker
public class ApplicationPackageLockingPolicyDefinitionArgsBuilder internal constructor() {
    private var allowedActions: Output<List<String>>? = null

    private var allowedDataActions: Output<List<String>>? = null

    /**
     * @param value The deny assignment excluded actions.
     */
    @JvmName("piujapwldvmpmiqg")
    public suspend fun allowedActions(`value`: Output<List<String>>) {
        this.allowedActions = value
    }

    @JvmName("ctmvmlbvdqdsreis")
    public suspend fun allowedActions(vararg values: Output<String>) {
        this.allowedActions = Output.all(values.asList())
    }

    /**
     * @param values The deny assignment excluded actions.
     */
    @JvmName("tvkcvhyromhcppoo")
    public suspend fun allowedActions(values: List<Output<String>>) {
        this.allowedActions = Output.all(values)
    }

    /**
     * @param value The deny assignment excluded data actions.
     */
    @JvmName("pdliobgiudinwfuf")
    public suspend fun allowedDataActions(`value`: Output<List<String>>) {
        this.allowedDataActions = value
    }

    @JvmName("dunfopxshoaqwqtf")
    public suspend fun allowedDataActions(vararg values: Output<String>) {
        this.allowedDataActions = Output.all(values.asList())
    }

    /**
     * @param values The deny assignment excluded data actions.
     */
    @JvmName("monupruaknojlauk")
    public suspend fun allowedDataActions(values: List<Output<String>>) {
        this.allowedDataActions = Output.all(values)
    }

    /**
     * @param value The deny assignment excluded actions.
     */
    @JvmName("yujwobcvwbqgewfo")
    public suspend fun allowedActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedActions = mapped
    }

    /**
     * @param values The deny assignment excluded actions.
     */
    @JvmName("rqrwlguggjirliai")
    public suspend fun allowedActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedActions = mapped
    }

    /**
     * @param value The deny assignment excluded data actions.
     */
    @JvmName("swciuntipwntbiec")
    public suspend fun allowedDataActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedDataActions = mapped
    }

    /**
     * @param values The deny assignment excluded data actions.
     */
    @JvmName("jtaelnnhagtbvhtp")
    public suspend fun allowedDataActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedDataActions = mapped
    }

    internal fun build(): ApplicationPackageLockingPolicyDefinitionArgs =
        ApplicationPackageLockingPolicyDefinitionArgs(
            allowedActions = allowedActions,
            allowedDataActions = allowedDataActions,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/solutions/kotlin/inputs/ApplicationPackageLockingPolicyDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.solutions.kotlin.inputs

import com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Managed application locking policy.
 * @property allowedActions The deny assignment excluded actions.
 * @property allowedDataActions The deny assignment excluded data actions.
 */
public data class ApplicationPackageLockingPolicyDefinitionArgs(
    public val allowedActions: Output<List<String>>? = null,
    public val allowedDataActions: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs =
        com.pulumi.azurenative.solutions.inputs.ApplicationPackageLockingPolicyDefinitionArgs.builder()
            .allowedActions(allowedActions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .allowedDataActions(
                allowedDataActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationPackageLockingPolicyDefinitionArgs].
 */
@PulumiTagMarker
public class ApplicationPackageLockingPolicyDefinitionArgsBuilder internal constructor() {
    private var allowedActions: Output<List<String>>? = null

    private var allowedDataActions: Output<List<String>>? = null

    /**
     * @param value The deny assignment excluded actions.
     */
    @JvmName("hoorpunlmehchkes")
    public suspend fun allowedActions(`value`: Output<List<String>>) {
        this.allowedActions = value
    }

    @JvmName("bifbyfxbdubdtibg")
    public suspend fun allowedActions(vararg values: Output<String>) {
        this.allowedActions = Output.all(values.asList())
    }

    /**
     * @param values The deny assignment excluded actions.
     */
    @JvmName("ffopulmvttbqdwva")
    public suspend fun allowedActions(values: List<Output<String>>) {
        this.allowedActions = Output.all(values)
    }

    /**
     * @param value The deny assignment excluded data actions.
     */
    @JvmName("fjkdsjvwjotujemh")
    public suspend fun allowedDataActions(`value`: Output<List<String>>) {
        this.allowedDataActions = value
    }

    @JvmName("rhmdcexvkgbskdsn")
    public suspend fun allowedDataActions(vararg values: Output<String>) {
        this.allowedDataActions = Output.all(values.asList())
    }

    /**
     * @param values The deny assignment excluded data actions.
     */
    @JvmName("ngknxdxdgtpdxrns")
    public suspend fun allowedDataActions(values: List<Output<String>>) {
        this.allowedDataActions = Output.all(values)
    }

    /**
     * @param value The deny assignment excluded actions.
     */
    @JvmName("pwjgeixcssadegom")
    public suspend fun allowedActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedActions = mapped
    }

    /**
     * @param values The deny assignment excluded actions.
     */
    @JvmName("wrohomobtveiojhg")
    public suspend fun allowedActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedActions = mapped
    }

    /**
     * @param value The deny assignment excluded data actions.
     */
    @JvmName("hcjgajrtokrxhiyb")
    public suspend fun allowedDataActions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedDataActions = mapped
    }

    /**
     * @param values The deny assignment excluded data actions.
     */
    @JvmName("vonuetofpusqdtxp")
    public suspend fun allowedDataActions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedDataActions = mapped
    }

    internal fun build(): ApplicationPackageLockingPolicyDefinitionArgs =
        ApplicationPackageLockingPolicyDefinitionArgs(
            allowedActions = allowedActions,
            allowedDataActions = allowedDataActions,
        )
}
